==> smart-testauto-framework-6.0.0-sources.jar: org/uitnet/testing/smartfwk/api/core/support/MultipartData.java <==
/*
 * SmartTestAutoFramework
 * Copyright 2021 and beyond
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 */
package org.uitnet.testing.smartfwk.api.core.support;

/**
 * 
 * @author Madhav Krishna
 *
 */
public class MultipartData {
	public String name;
	public String contentType;
	public String fileName;
	public String filePath;
	public byte[] fileContents;

	public MultipartData() {
		contentType = "application/octet-stream";
	}

	public MultipartData(String name, String fileName, String contentType, String filePath) {
		this.name = name;
		this.fileName = fileName;
		this.contentType = contentType;
		this.filePath = filePath;
	}
	
	public MultipartData(String name, String fileName, String contentType, byte[] fileContents) {
		this.name = name;
		this.fileName = fileName;
		this.contentType = contentType;
		this.fileContents = fileContents;
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public String getContentType() {
		return contentType;
	}

	public void setContentType(String contentType) {
		this.contentType = contentType;
	}

	public String getFileName() {
		return fileName;
	}

	public void setFileName(String fileName) {
		this.fileName = fileName;
	}

	public String getFilePath() {
		return filePath;
	}

	public void setFilePath(String filePath) {
		this.filePath = filePath;
	}

	public byte[] getFileContents() {
		return fileContents;
	}

	public void setFileContents(byte[] fileContents) {
		this.fileContents = fileContents;
	}
}

==> smart-testauto-framework-6.0.13-sources.jar: org/uitnet/testing/smartfwk/api/core/support/MultipartData.java <==
/*
 * SmartTestAutoFramework
 * Copyright 2021 and beyond
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 */
package org.uitnet.testing.smartfwk.api.core.support;

/**
 * 
 * @author Madhav Krishna
 *
 */
public class MultipartData {
	public String name;
	public String contentType;
	public String fileName;
	public String filePath;
	public byte[] fileContents;

	public MultipartData() {
		contentType = "application/octet-stream";
	}

	public MultipartData(String name, String fileName, String contentType, String filePath) {
		this.name = name;
		this.fileName = fileName;
		this.contentType = contentType;
		this.filePath = filePath;
	}
	
	public MultipartData(String name, String fileName, String contentType, byte[] fileContents) {
		this.name = name;
		this.fileName = fileName;
		this.contentType = contentType;
		this.fileContents = fileContents;
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public String getContentType() {
		return contentType;
	}

	public void setContentType(String contentType) {
		this.contentType = contentType;
	}

	public String getFileName() {
		return fileName;
	}

	public void setFileName(String fileName) {
		this.fileName = fileName;
	}

	public String getFilePath() {
		return filePath;
	}

	public void setFilePath(String filePath) {
		this.filePath = filePath;
	}

	public byte[] getFileContents() {
		return fileContents;
	}

	public void setFileContents(byte[] fileContents) {
		this.fileContents = fileContents;
	}
	
	@Override
	public String toString() {
		StringBuilder builder = new StringBuilder();
		builder.append("\nname: " + name)
		.append("\ncontentType: " + contentType)
		.append("\nfileName: " + fileName)
		.append("\nfilePath: " + filePath)
		.append("\nfileContents: " + fileContents);
		
		return builder.toString();
	}
}
